==> accumulo-2.1.4-src.tar.gz: accumulo-2.1.4/core/src/main/java/org/apache/accumulo/core/clientImpl/ZookeeperLockChecker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.core.clientImpl;

import org.apache.accumulo.core.Constants;
import org.apache.accumulo.core.clientImpl.TabletLocatorImpl.TabletServerLockChecker;
import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
import org.apache.accumulo.core.fate.zookeeper.ZooCache;

public class ZookeeperLockChecker implements TabletServerLockChecker {

  private final ZooCache zc;
  private final String root;

  ZookeeperLockChecker(ClientContext context) {
    zc = context.getZooCache();
    this.root = context.getZooKeeperRoot() + Constants.ZTSERVERS;
  }

  public boolean doesTabletServerLockExist(String server) {
    var zLockPath = ServiceLock.path(root + "/" + server);
    return ServiceLock.getSessionId(zc, zLockPath) != 0;
  }

  @Override
  public boolean isLockHeld(String tserver, String session) {
    var zLockPath = ServiceLock.path(root + "/" + tserver);
    return ServiceLock.getSessionId(zc, zLockPath) == Long.parseLong(session, 16);
  }

  @Override
  public void invalidateCache(String tserver) {
    zc.clear(root + "/" + tserver);
  }

}

==> accumulo-3.0.0-src.tar.gz: accumulo-3.0.0/core/src/main/java/org/apache/accumulo/core/clientImpl/ZookeeperLockChecker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.accumulo.core.clientImpl;

import org.apache.accumulo.core.Constants;
import org.apache.accumulo.core.clientImpl.TabletLocatorImpl.TabletServerLockChecker;
import org.apache.accumulo.core.fate.zookeeper.ZooCache;
import org.apache.accumulo.core.lock.ServiceLock;

public class ZookeeperLockChecker implements TabletServerLockChecker {

  private final ZooCache zc;
  private final String root;

  ZookeeperLockChecker(ClientContext context) {
    zc = context.getZooCache();
    this.root = context.getZooKeeperRoot() + Constants.ZTSERVERS;
  }

  @Override
  public boolean isLockHeld(String tserver, String session) {
    var zLockPath = ServiceLock.path(root + "/" + tserver);
    return ServiceLock.getSessionId(zc, zLockPath) == Long.parseLong(session, 16);
  }

  @Override
  public void invalidateCache(String tserver) {
    zc.clear(root + "/" + tserver);
  }

}
